# git-ea

git-ea is the base command

```
git-ea
├─ backport
├─ branch
├─ cd
├─ cleanup
├─ frontport
├─ ide
├─ init
├─ post
├─ pr
└─ tag
```


```
[--help]
[--version,-v]
```
**Usage**:

```
git-ea <cmd>
```

**--help**: Show help


**--version,-v**: Print git-ea version


-----

## backport

backport cherry-picks a commit and applies it to a clean branch based on `release`


```
[--from,-f]=[value]
[--help]
[--list,-l]
[--push,-p]
[--to,-t]=[value]
```
**Usage**:

```
backport --from [release=main] --to [release=latest]
```

**--from,-f**="": Release to backport from (ex: `main`, default: main)


**--help**: Show help


**--list,-l**: Open repository to see needed backports


**--push,-p**: Push immediately


**--to,-t**="": Release to backport to (ex: `17`, default: `latest`)


-----

## branch

branch creates a new branch called `name` based on `base`


```
[--base,-b]=[value]
[--help]
[--ide,-i]
[--list,-l]
[--no-fetch,-n]
```
**Usage**:

```
branch --base [ref=main] <name>
```

**--base,-b**="": Ref to base from (default: `main`)


**--help**: Show help


**--ide,-i**: Open an IDE for the new branch


**--list,-l**: List branches available


**--no-fetch,-n**: Skip fetching


-----

## cleanup

cleanup removes named branches, or interactive if no arguments


```
[--force,-f]
[--help]
[--prune,-p]
```
**Usage**:

```
cleanup [branches...]
```

**--force,-f**: Force cleanup


**--help**: Show help


**--prune,-p**: Prune worktrees


-----

## cd

Open a shell in the specified `workspace`


```
[--help]
[--print,-p]
```
**Usage**:

```
cd [workspace=base]
```

**--help**: Show help


**--print,-p**: Print workspace dir instead of spawning a shell


-----

## frontport

frontport cherry-picks a commit and applies it to a clean branch based on `release`


```
[--from,-f]=[value]
[--help]
[--push,-p]
[--to,-t]=[value]
```
**Usage**:

```
frontport --from [release=latest] --to [release=main]
```

**--from,-f**="": Release to frontport from (ex: `17`, default: <latest>)


**--help**: Show help


**--push,-p**: Push immediately


**--to,-t**="": Release to frontport to (ex: `main`, default: `main`)


-----

## ide

ide starts an IDE for `branch`


```
[--gui,-g]
[--help]
```
**Usage**:

```
ide <branch>
```

**--gui,-g**: Prefer GUI editor


**--help**: Show help


-----

## init

init initializes a workspace for Gitea


```
[--help]
```
**Usage**:

```
init
```

**--help**: Show help


-----

## post

post creates a new blog release post


```
[--author,-a]=[value]
[--changelog,-c]=[value]
[--help]
[--milestone,-m]=[value]
[--output,-o]=[value]
```
**Usage**:

```
post
```

**--author,-a**="": Post author


**--changelog,-c**="": Post changelog (no header)


**--help**: Show help


**--milestone,-m**="": Post milestone


**--output,-o**="": Output file (default: `content/post/release-of-${milestone}.md`)


-----

## pr

pr pulls down a pull request for testing


```
[--help]
[--ide,-i]
```
**Usage**:

```
pr <index>
```

**--help**: Show help


**--ide,-i**: Start an IDE for this PR


-----

## tag

tag makes a signed tag for `branch`


```
[--help]
[--push,-p]
```
**Usage**:

```
tag <branch>
```

**--help**: Show help


**--push,-p**: Push immediately


-----

